1.0.0 (2013-03-18)
------------------

- Python 3 compatibile
- Changed convenience import: `encode` replaces `encoder`
- Added convenience methods to Table to allow direct encoding as JSON and a
  Google data source.

0.9.1 (2012-07-26)
------------------

- Changed signature of add_column when I found I used it wrongly myself in
the docs


0.9 (2012-07-25)
----------------

- Initial release
